==> marketing_plugin-0.0.6.tar.gz: ios/Classes/PluginCodelabPlugin.swift <==
import Flutter
import UIKit

public class PluginCodelabPlugin: NSObject, FlutterPlugin {
    static var admodel : AdModel?
    
    public static func register(with registrar: FlutterPluginRegistrar) {
        let channel = FlutterMethodChannel(name: "ads", binaryMessenger: registrar.messenger())
        let instance = PluginCodelabPlugin()
        registerNativeView(registrar: registrar)
        getApiDatas()
        registrar.addMethodCallDelegate(instance, channel: channel)
    }
    
    static func registerNativeView(registrar: FlutterPluginRegistrar){
        let factory = FLNativeViewFactory(messenger: registrar.messenger())
        let bannerFactory = FLBannerViewFactory(messenger:registrar.messenger())
        registrar.register(factory, withId: "plugins/blur_view_widget")
        registrar.register(bannerFactory, withId:"plugins/blur_view_banner_widget")
    }
    public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
        if(call.method == "quiz"){
            result(PluginCodelabPlugin.admodel?.qlink ?? "")
        }
        else if(call.method == "isAD"){
            result(PluginCodelabPlugin.admodel?.isad ?? false)
        } else if(call.method == "isQuizeAd"){
            result(PluginCodelabPlugin.admodel?.isqurekaads ?? false)
        } else if(call.method == "onesignalKey"){
            result(PluginCodelabPlugin.admodel?.oneSignalApp ?? "")
        }else if(call.method == "privacyPolicy"){
            result(PluginCodelabPlugin.admodel?.privacypolicy ?? "")
        }else if(call.method == "dummyScreen"){
            result(PluginCodelabPlugin.admodel?.isdummyscreen ?? false)
        }else if(call.method == "loaderUrl"){
            result(PluginCodelabPlugin.admodel?.loaderURL ?? "")
        }else if(call.method == "issdkads"){
            result(PluginCodelabPlugin.admodel?.issdkads ?? false)
        }else if(call.method == "FBrewardedAd"){
            result(PluginCodelabPlugin.admodel?.fBrewardedAd ?? "")
        }else if(call.method == "FBinterstitialAd"){
            result(PluginCodelabPlugin.admodel?.fBinterstitialAd ?? "")
        }else if(call.method == "FBnativeAd"){
            result(PluginCodelabPlugin.admodel?.fBnativeAd ?? "")
        }else if(call.method == "FBbannerAd"){
            result(PluginCodelabPlugin.admodel?.fBbannerAd ?? "")
        }else if(call.method == "isEveryads"){
            result(PluginCodelabPlugin.admodel?.iseveryads ?? false)
        }else if(call.method == "isfacebookads"){
            result(PluginCodelabPlugin.admodel?.isopenmediation ?? false)
        }else if(call.method == "isBackgroudAds"){
            result(PluginCodelabPlugin.admodel?.isbackgroundads ?? false)
        }else if(call.method == "colors"){
            let colors = [
                "background" : PluginCodelabPlugin.admodel?.customBackgroundColor ?? "",
                "button" : PluginCodelabPlugin.admodel?.customButtoncolor ?? "",
                "text" : PluginCodelabPlugin.admodel?.customTextcolor ?? "",
                "title" : PluginCodelabPlugin.admodel?.customTitleColor ?? ""
            ] as [String : Any]
            
            result(colors)
        }else if(call.method == "adManagerIds"){
            let colors = [
                "banner" : PluginCodelabPlugin.admodel?.bannerAd ?? "",
                "native" : PluginCodelabPlugin.admodel?.nativeAd ?? "",
                "interstitial" : PluginCodelabPlugin.admodel?.interstitial ?? "",
                "reward" : PluginCodelabPlugin.admodel?.fBrewardedAd ?? ""
                "appOpenUnitId" : PluginCodelabPlugin.admodel?.adOpen ?? ""
            ] as [String : Any]
            
            result(colors)
        }else if(call.method == "isCustomeads"){
            result(PluginCodelabPlugin.admodel?.iscustomeads ?? false)
        }else if(call.method == "isnativead"){
            result(PluginCodelabPlugin.admodel?.isnativeenable ?? false)
        }else if(call.method == "isrecycleAds"){
            result(PluginCodelabPlugin.admodel?.recyclenative ?? false)
        }
    }
    
    static func getApiDatas(){
        let session = URLSession.shared
        let url = URL(string: "http://erpsystem.sattechnolab.com/api/app_json?bundleName="+Bundle.main.bundleIdentifier!)!
        //         let url = URL(string: "http://erpsystem.sattechnolab.com/api/app_json?bundleName=com.chat.aigpt")!
        
        
        let task = session.dataTask(with: url) { data, response, error in
            
            if error != nil || data == nil {
                print("Client error!")
                return
            }
            
            guard let response = response as? HTTPURLResponse, (200...299).contains(response.statusCode) else {
                print("Server error!")
                return
            }
            do {
                let json = try JSONSerialization.jsonObject(with: data!, options: [])
                
                let admodels = try JSONDecoder().decode(AdModel.self, from: data!)
                print("The Response is : ",json)
                self.admodel = admodels;
                
                
            } catch {
                print("JSON error: \(error.localizedDescription)")
            }
            
        }
        task.resume()
    }
}

==> marketing_plugin-0.0.9.tar.gz: ios/Classes/PluginCodelabPlugin.swift <==
import Flutter
import UIKit

public class PluginCodelabPlugin: NSObject, FlutterPlugin {
    static var admodel : AdModel?
    
    public static func register(with registrar: FlutterPluginRegistrar) {
        let channel = FlutterMethodChannel(name: "ads", binaryMessenger: registrar.messenger())
        let instance = PluginCodelabPlugin()
        registerNativeView(registrar: registrar)
        getApiDatas()
        registrar.addMethodCallDelegate(instance, channel: channel)
    }
    
    static func registerNativeView(registrar: FlutterPluginRegistrar){
        let factory = FLNativeViewFactory(messenger: registrar.messenger())
        let bannerFactory = FLBannerViewFactory(messenger:registrar.messenger())
        registrar.register(factory, withId: "plugins/blur_view_widget")
        registrar.register(bannerFactory, withId:"plugins/blur_view_banner_widget")
    }
    public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
        if(call.method == "quiz"){
            result(PluginCodelabPlugin.admodel?.qlink ?? "")
        }
        else if(call.method == "isAD"){
            result(PluginCodelabPlugin.admodel?.isad ?? false)
        } else if(call.method == "isQuizeAd"){
            result(PluginCodelabPlugin.admodel?.isqurekaads ?? false)
        } else if(call.method == "onesignalKey"){
            result(PluginCodelabPlugin.admodel?.oneSignalApp ?? "")
        }else if(call.method == "privacyPolicy"){
            result(PluginCodelabPlugin.admodel?.privacypolicy ?? "")
        }else if(call.method == "dummyScreen"){
            result(PluginCodelabPlugin.admodel?.isdummyscreen ?? false)
        }else if(call.method == "loaderUrl"){
            result(PluginCodelabPlugin.admodel?.loaderURL ?? "")
        }else if(call.method == "issdkads"){
            result(PluginCodelabPlugin.admodel?.issdkads ?? false)
        }else if(call.method == "FBrewardedAd"){
            result(PluginCodelabPlugin.admodel?.fBrewardedAd ?? "")
        }else if(call.method == "FBinterstitialAd"){
            result(PluginCodelabPlugin.admodel?.fBinterstitialAd ?? "")
        }else if(call.method == "FBnativeAd"){
            result(PluginCodelabPlugin.admodel?.fBnativeAd ?? "")
        }else if(call.method == "FBbannerAd"){
            result(PluginCodelabPlugin.admodel?.fBbannerAd ?? "")
        }else if(call.method == "isEveryads"){
            result(PluginCodelabPlugin.admodel?.iseveryads ?? false)
        }else if(call.method == "isfacebookads"){
            result(PluginCodelabPlugin.admodel?.isopenmediation ?? false)
        }else if(call.method == "isBackgroudAds"){
            result(PluginCodelabPlugin.admodel?.isbackgroundads ?? false)
        }else if(call.method == "colors"){
            let colors = [
                "background" : PluginCodelabPlugin.admodel?.customBackgroundColor ?? "",
                "button" : PluginCodelabPlugin.admodel?.customButtoncolor ?? "",
                "text" : PluginCodelabPlugin.admodel?.customTextcolor ?? "",
                "title" : PluginCodelabPlugin.admodel?.customTitleColor ?? ""
            ] as [String : Any]
            
            result(colors)
        }else if(call.method == "adManagerIds"){
            let colors = [
                "banner" : PluginCodelabPlugin.admodel?.bannerAd ?? "",
                "native" : PluginCodelabPlugin.admodel?.nativeAd ?? "",
                "interstitial" : PluginCodelabPlugin.admodel?.interstitial ?? "",
                "reward" : PluginCodelabPlugin.admodel?.fBrewardedAd ?? "",
                "appOpenUnitId" : PluginCodelabPlugin.admodel?.adOpen ?? ""
            ] as [String : Any]
            
            result(colors)
        }else if(call.method == "isCustomeads"){
            result(PluginCodelabPlugin.admodel?.iscustomeads ?? false)
        }else if(call.method == "isnativead"){
            result(PluginCodelabPlugin.admodel?.isnativeenable ?? false)
        }else if(call.method == "isrecycleAds"){
            result(PluginCodelabPlugin.admodel?.recyclenative ?? false)
        }
    }
    
    static func getApiDatas(){
        let session = URLSession.shared
        let url = URL(string: "http://erpsystem.sattechnolab.com/api/app_json?bundleName="+Bundle.main.bundleIdentifier!)!
        //         let url = URL(string: "http://erpsystem.sattechnolab.com/api/app_json?bundleName=com.chat.aigpt")!
        
        
        let task = session.dataTask(with: url) { data, response, error in
            
            if error != nil || data == nil {
                print("Client error!")
                return
            }
            
            guard let response = response as? HTTPURLResponse, (200...299).contains(response.statusCode) else {
                print("Server error!")
                return
            }
            do {
                let json = try JSONSerialization.jsonObject(with: data!, options: [])
                
                let admodels = try JSONDecoder().decode(AdModel.self, from: data!)
                print("The Response is : ",json)
                self.admodel = admodels;
                
                
            } catch {
                print("JSON error: \(error.localizedDescription)")
            }
            
        }
        task.resume()
    }
}
